@@ -11,9 +11,11 @@
 //
 
 #include "srcuntabifier.h"
-#include "my_sstream.h"
+#include <sstream>
 #include <boost/regex.hpp>
 
+namespace srchilite {
+
 const boost::regex tabexp("[\\t]");
 
 const string Untabifier::doPreformat(const string &s) {
@@ -29,7 +31,7 @@ const string Untabifier::doPreformat(const string &s) {
         return s;
     }
 
-    ostringstream buffer;
+    std::ostringstream buffer;
     string prefix;
     string suffix;
 
@@ -53,3 +55,5 @@ const string Untabifier::doPreformat(const string &s) {
 
     return buffer.str();
 }
+
+}
